@@ -1,17 +1,17 @@
-/*  File src/wtchangestats.h in package ergm.count, part of the Statnet suite
- *  of packages for network analysis, https://statnet.org .
+/*  File src/wtchangestats.h in package ergm.count, part of the
+ *  Statnet suite of packages for network analysis, https://statnet.org .
  *
  *  This software is distributed under the GPL-3 license.  It is free,
  *  open source, and has the attribution requirements (GPL Section 7) at
- *  https://statnet.org/attribution
+ *  https://statnet.org/attribution .
  *
- *  Copyright 2008-2019 Statnet Commons
+ *  Copyright 2008-2021 Statnet Commons
  */
 #ifndef WTCHANGESTATS_H
 #define WTCHANGESTATS_H
 
-#include "wtedgetree.h"
-#include "wtchangestat.h"
+#include "ergm_wtedgetree.h"
+#include "ergm_wtchangestat.h"
 
 /********************  changestats:   S    ***********/
 WtD_CHANGESTAT_FN(d_sumlogfactorial);
